Limiter
Limiter()Enumeration of limiter types used for slope limiting in the numerical solution of the shallow water equations.
Attributes
| Name | Type | Description |
|---|---|---|
| Koren | int | Koren limiter |
| MC | int | Monotonized Central (MC) limiter |
| MC_minmod | int | Hybrid Monotonized Central (MC) and minmod limiter with minmod applied to low flow thicknesses (<1cm) |
| minmod | int | Minmod limiter |
| superbee | int | Superbee limiter |
| vanAlbada | int | Van Albada symmetric limiter |
| vanLeer | int | Van Leer limiter |
| vanLeer_minmod | int | Hybrid Van Leer and minmod limiter with minmod applied to low flow thicknesses (<1cm) |